@@ -158,6 +158,8 @@ class DiskBuilder:
         self.dracut_setup = xml_state.get_dracut_config('setup')
         self.dracut_add_modules = xml_state.get_dracut_config('add').modules
         self.dracut_omit_modules = xml_state.get_dracut_config('omit').modules
+        self.dracut_add_drivers = xml_state.get_dracut_config('add').drivers
+        self.dracut_omit_drivers = xml_state.get_dracut_config('omit').drivers
         self.mdraid = xml_state.build_type.get_mdraid()
         self.hybrid_mbr = xml_state.build_type.get_gpt_hybrid_mbr()
         self.force_mbr = xml_state.build_type.get_force_mbr()
@@ -803,6 +805,10 @@ class DiskBuilder:
                 self.boot_image.include_module(module)
             for module in self.dracut_omit_modules:
                 self.boot_image.omit_module(module)
+            for driver in self.dracut_add_drivers:
+                self.boot_image.include_driver(driver)
+            for driver in self.dracut_omit_drivers:
+                self.boot_image.omit_driver(driver)
             if self.root_filesystem_is_multipath is False:
                 self.boot_image.omit_module('multipath')
             if self.root_filesystem_is_overlay:
@@ -1133,7 +1139,7 @@ class DiskBuilder:
             )
             partition_mbsize = self.disk_setup.boot_partition_size()
             disk.create_boot_partition(
-                partition_mbsize, self.boot_clone_count
+                format(partition_mbsize), self.boot_clone_count
             )
             disksize_used_mbytes += \
                 (self.boot_clone_count + 1) * partition_mbsize if \
@@ -1189,9 +1195,19 @@ class DiskBuilder:
                 (self.root_clone_count + 1) * squashed_rootfs_mbsize if \
                 self.root_clone_count else squashed_rootfs_mbsize
 
+        root_clone_count = self.root_clone_count
+        if self.root_filesystem_is_overlay:
+            # in overlay mode an eventual root clone is created from
+            # the root readonly partition and not from the root (rw)
+            # partition. Thus no further action needed here in this
+            # case
+            root_clone_count = 0
+
         if self.spare_part_mbsize and self.spare_part_is_last:
             rootfs_mbsize = disksize_mbytes - disksize_used_mbytes - \
                 self.spare_part_mbsize - Defaults.get_min_partition_mbytes()
+            if root_clone_count:
+                rootfs_mbsize = int(rootfs_mbsize / (root_clone_count + 1))
         else:
             if self.oem_systemsize and not self.oem_resize:
                 rootfs_mbsize = self.oem_systemsize
@@ -1209,18 +1225,13 @@ class DiskBuilder:
                 '--> overlayroot explicitly requested no write partition'
             )
         else:
-            root_clone_count = self.root_clone_count
-            if self.root_filesystem_is_overlay:
-                # in overlay mode an eventual root clone is created from
-                # the root readonly partition and not from the root (rw)
-                # partition. Thus no further action needed here in this
-                # case
-                root_clone_count = 0
             if root_clone_count:
                 if rootfs_mbsize == 'all_free':
+                    clone_rootfs_mbsize = disksize_mbytes - \
+                        disksize_used_mbytes - Defaults.get_min_partition_mbytes()
                     clone_rootfs_mbsize = int(
-                        (disksize_mbytes - disksize_used_mbytes) / (root_clone_count + 1)
-                    ) + Defaults.get_min_partition_mbytes()
+                        clone_rootfs_mbsize / (root_clone_count + 1)
+                    )
                     rootfs_mbsize = \
                         f'clone:{clone_rootfs_mbsize}:{clone_rootfs_mbsize}'
                 else:
@@ -1247,7 +1258,7 @@ class DiskBuilder:
                 )
                 disk.create_root_partition(rootfs_mbsize, root_clone_count)
 
-        if self.spare_part_mbsize and self.spare_part_is_last:
+        if self.spare_part_is_last:
             log.info('--> creating spare partition')
             disk.create_spare_partition(
                 'all_free'
@@ -1714,8 +1725,8 @@ class DiskBuilder:
                 Command.run(
                     [
                         'dd',
-                        'if=%s' % squashed_root_file.name,
-                        'of=%s' % readonly_target
+                        f'if={squashed_root_file.name}',
+                        f'of={readonly_target}'
                     ]
                 )
                 if self.root_filesystem_embed_verity_metadata:
@@ -1779,8 +1790,8 @@ class DiskBuilder:
             Command.run(
                 [
                     'dd',
-                    'if=%s' % verity_root_file.name,
-                    'of=%s' % root_target
+                    f'if={verity_root_file.name}',
+                    f'of={root_target}'
                 ]
             )
             if self.root_filesystem_embed_verity_metadata:
