@@ -76,6 +76,37 @@ class RuntimeChecker:
                 'No repositories configured'
             )
 
+    @staticmethod
+    def check_target_dir_on_unsupported_filesystem(target_dir: str) -> None:
+        """
+        Raise if the given target dir does not reside on a
+        filesystem that supports all important features like
+        extended permissions(fscaps), ACLs or xattrs.
+        """
+        message = dedent('''\n
+            Target root/image directory is lacking filesystem features
+
+            The filesystem {0} for the given image target directory {1}
+            does not support important features like extended permissions,
+            ACLs or xattrs. The image build may fail or the resulting
+            image misbehave.
+        ''')
+        stat = Command.run(['stat', '-f', '-c', '%T', target_dir])
+        if stat:
+            target_fs = stat.output.strip()
+            supported_target_filesystem = (
+                'btrfs',
+                'ext2',
+                'ext2/ext3',
+                'ext3',
+                'ext4',
+                'overlayfs',
+                'tmpfs',
+                'xfs',
+            )
+            if target_fs not in supported_target_filesystem:
+                raise KiwiRuntimeError(message.format(target_fs, target_dir))
+
     def check_include_references_unresolvable(self) -> None:
         """
         Raise for still included <include> statements as not resolvable.
@@ -838,35 +869,6 @@ class RuntimeChecker:
                     message.format(required_dracut_packages)
                 )
 
-    def check_efi_mode_for_disk_overlay_correctly_setup(self) -> None:
-        """
-        Disk images configured to use a root filesystem overlay
-        only supports the standard EFI mode and not secure boot.
-        That's because the shim setup performs changes to the
-        root filesystem which can not be applied during the
-        bootloader setup at build time because at that point
-        the root filesystem is a read-only squashfs source.
-        """
-        message = dedent('''\n
-            Secure Boot not supported with overlay disk image
-
-            Disk images configured to use a root filesystem overlay
-            only supports the standard EFI mode and not secure boot.
-            That's because the shim setup performs changes to the
-            root filesystem which can not be applied during the
-            bootloader setup at build time because at that point
-            the root filesystem is a read-only squashfs source
-
-            Thus please change the firmware attribute in the <type>
-            section of the system XML description as follows:
-
-            <type ... firmware="efi"/>
-        ''')
-        overlayroot = self.xml_state.build_type.get_overlayroot()
-        firmware = self.xml_state.build_type.get_firmware()
-        if overlayroot and firmware == 'uefi':
-            raise KiwiRuntimeError(message)
-
     def check_xen_uniquely_setup_as_server_or_guest(self) -> None:
         """
         If the image is classified to be used as Xen image, it can
