@@ -71,7 +71,6 @@ class CliTask:
         # initialize generic runtime check dicts
         self.checks_before_command_args: Dict[str, List[str]] = {
             'check_image_version_provided': [],
-            'check_efi_mode_for_disk_overlay_correctly_setup': [],
             'check_initrd_selection_required': [],
             'check_boot_description_exists': [],
             'check_consistent_kernel_in_boot_and_system_image': [],
@@ -160,7 +159,6 @@ class CliTask:
             kiwi searches for a file named config.xml or
             a file matching .kiwi
         """
-        log.info('Loading XML description')
         if kiwi_file:
             config_file = os.sep.join([description_directory, kiwi_file])
         else:
@@ -177,7 +175,7 @@ class CliTask:
 
         if not os.path.exists(config_file):
             raise KiwiConfigFileNotFound(
-                'no XML description found in %s' % description_directory
+                f'no XML description found in {description_directory}'
             )
 
         self.description = XMLDescription(
@@ -222,12 +220,12 @@ class CliTask:
         """
         return self._ntuple_token(option, 4)
 
-    def tentuple_token(
+    def eleventuple_token(
         self, option: str
     ) -> List[Union[bool, str, List[str], None]]:
         """
         Helper method for commandline options of the
-        form --option a,b,c,d,e,f,g,h,i,j
+        form --option a,b,c,d,e,f,g,h,i,j,k
 
         Make sure to provide a common result for option values which
         separates the information in a comma separated list of values
@@ -238,7 +236,7 @@ class CliTask:
 
         :rtype: list
         """
-        return self._ntuple_token(option, 10)
+        return self._ntuple_token(option, 11)
 
     def attr_token(
         self, option: str
