@@ -321,7 +321,7 @@ class TestDiskBuilder:
             self.firmware.get_efi_partition_size()
         )
         disk.create_boot_partition.assert_called_once_with(
-            self.disk_setup.boot_partition_size(), 0
+            format(self.disk_setup.boot_partition_size()), 0
         )
         disk.create_swap_partition.assert_called_once_with(
             '128'
@@ -567,10 +567,10 @@ class TestDiskBuilder:
             self.disk_builder.create_disk()
 
         disk.create_boot_partition.assert_called_once_with(
-            self.disk_setup.boot_partition_size(), 1
+            format(self.disk_setup.boot_partition_size()), 1
         )
         disk.create_root_partition.assert_called_once_with(
-            'clone:458:458', 1
+            'clone:443:443', 1
         )
         disk.create_custom_partitions.assert_called_once_with(
             self.disk_builder.custom_partitions
@@ -581,10 +581,23 @@ class TestDiskBuilder:
             call([self.device_map['rootclone1']])
         ]
 
+        # Test in spare part mode
+        self.disk_builder.spare_part_mbsize = 42
+        self.disk_builder.spare_part_is_last = True
+        disk.create_root_partition.reset_mock()
+        with patch('builtins.open', m_open, create=True):
+            self.disk_builder.create_disk()
+
+        disk.create_root_partition.assert_called_once_with(
+            'clone:422:422', 1
+        )
+
         # Test in overlay mode a root clone is created from
         # the root readonly partition and not from the root (rw)
         # partition.
         self.disk_builder.root_filesystem_is_overlay = True
+        self.disk_builder.spare_part_mbsize = None
+        self.disk_builder.spare_part_is_last = False
         disk.create_root_partition.reset_mock()
         with patch('builtins.open', m_open, create=True):
             self.disk_builder.create_disk()
@@ -833,7 +846,7 @@ class TestDiskBuilder:
             self.firmware.get_efi_partition_size()
         )
         disk.create_boot_partition.assert_called_once_with(
-            self.disk_setup.boot_partition_size(), 0
+            format(self.disk_setup.boot_partition_size()), 0
         )
         disk.create_prep_partition.assert_called_once_with(
             self.firmware.get_prep_partition_size()
@@ -1041,9 +1054,11 @@ class TestDiskBuilder:
         block_operation.get_filesystem.return_value = 'ext3'
         mock_BlockID.return_value = block_operation
         mock_rand.return_value = 15
-        self.disk_builder.dracut_setup = DracutT(uefi=True, modules=[])
+        self.disk_builder.dracut_setup = DracutT(uefi=True, modules=[], drivers=[])
         self.disk_builder.dracut_add_modules = ['some']
         self.disk_builder.dracut_omit_modules = ['some']
+        self.disk_builder.dracut_add_drivers = ['driver1']
+        self.disk_builder.dracut_omit_drivers = ['driver2']
         self.disk_builder.root_filesystem_is_overlay = True
         self.disk_builder.root_filesystem_has_write_partition = False
         self.disk_builder.root_filesystem_verity_blocks = 10
@@ -1124,6 +1139,8 @@ class TestDiskBuilder:
         assert self.boot_image_task.omit_module.call_args_list == [
             call('some'), call('multipath')
         ]
+        self.boot_image_task.include_driver.assert_called_once_with('driver1')
+        self.boot_image_task.omit_driver.assert_called_once_with('driver2')
         self.boot_image_task.write_system_config_file.assert_called_once_with(
             config={'modules': ['kiwi-overlay']}
         )
