@@ -465,6 +465,7 @@ class TestXMLState:
         c1 = containers[0]
         c2 = containers[1]
         c3 = containers[2]
+        c4 = containers[3]
 
         c1.fetch_command('root_dir')
         assert c1.name == 'rmtserver_latest'
@@ -525,6 +526,27 @@ class TestXMLState:
                 'foo_latest:docker.io/foo:latest'
             ]
         )
+        mock_Command_run.reset_mock()
+
+        c4.fetch_command('root_dir')
+        assert c4.name == 'test-app_v1.0'
+        assert c4.backend == 'container-snap'
+        assert c4.container_file == \
+            '/var/tmp/kiwi_containers/test-app_v1.0'
+        assert c4.fetch_only is False
+        assert c4.load_command == [
+            '/usr/bin/container-snap', 'load', '-i',
+            '/var/tmp/kiwi_containers/test-app_v1.0'
+        ]
+        mock_Command_run.assert_called_once_with(
+            [
+                'chroot', 'root_dir',
+                '/usr/bin/skopeo', 'copy',
+                'docker://registry.example.com/test-app:v1.0',
+                'oci-archive:/var/tmp/kiwi_containers/'
+                'test-app_v1.0:registry.example.com/test-app:v1.0'
+            ]
+        )
 
     def test_get_volumes_custom_root_volume_name(self):
         description = XMLDescription(
@@ -1260,12 +1282,21 @@ class TestXMLState:
         state = XMLState(xml_data, ['vmxSimpleFlavour'], 'oem')
         assert state.get_installmedia_initrd_modules('add') == []
 
+    def test_get_installintrd_driver(self):
+        assert self.state.get_installmedia_initrd_drivers('add') == \
+            ['erofs']
+        assert self.state.get_installmedia_initrd_drivers('omit') == []
+        xml_data = self.description.load()
+        state = XMLState(xml_data, ['vmxSimpleFlavour'], 'oem')
+        assert state.get_installmedia_initrd_drivers('add') == []
+
     def test_get_dracut_config(self):
         assert self.state.get_dracut_config('setup').uefi is False
         xml_data = self.description.load()
         state = XMLState(xml_data, ['vmxSimpleFlavour'], 'oem')
         assert state.get_dracut_config('setup').uefi is True
         assert state.get_dracut_config('add').modules == ['some']
+        assert state.get_dracut_config('add').drivers == ['driver']
 
     @patch('kiwi.system.uri.os.path.abspath')
     def test_get_repositories_signing_keys(self, mock_root_path):
